==> found-relay-0.8.1.tgz: package/es/QuerySubscription.js <==
import _filterInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/filter";
import _forEachInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/for-each";
import _Promise from "@babel/runtime-corejs3/core-js-stable/promise";
import { createOperationDescriptor, getRequest } from 'relay-runtime';

var QuerySubscription = /*#__PURE__*/function () {
  function QuerySubscription(_ref) {
    var _this = this;

    var environment = _ref.environment,
        query = _ref.query,
        variables = _ref.variables,
        cacheConfig = _ref.cacheConfig,
        fetchPolicy = _ref.fetchPolicy;

    this.onChange = function (snapshot) {
      _this.updateReadyState({
        error: null,
        props: snapshot.data,
        retry: _this.retry
      });
    };

    this.retry = function () {
      _this.retrying = true;
      _this.retryingAfterError = !!_this.readyState.error;

      _this.dispose();

      _this.execute(function () {});
    };

    this.environment = environment;
    this.query = query;
    this.variables = variables;
    this.cacheConfig = cacheConfig;
    this.fetchPolicy = fetchPolicy;
    this.operation = createOperationDescriptor(getRequest(query), variables);
    this.fetchPromise = null;
    this.selectionReference = null;
    this.pendingRequest = null;
    this.rootSubscription = null;
    this.retrying = false;
    this.retryingAfterError = false;
    this.readyState = {
      error: null,
      props: null,
      retry: null
    };
    this.listeners = [];
    this.relayContext = {
      environment: this.environment,
      variables: this.operation.request.variables
    };
  }

  var _proto = QuerySubscription.prototype;

  _proto.fetch = function fetch() {
    var _this2 = this;

    if (!this.fetchPromise) {
      this.fetchPromise = new _Promise(function (resolve) {
        _this2.execute(resolve);
      });
    }

    return this.fetchPromise;
  };

  _proto.execute = function execute(resolve) {
    var _this3 = this;

    var snapshot;
    this.selectionReference = this.retain();

    var onSnapshot = function onSnapshot() {
      if (snapshot) {
        return;
      }

      snapshot = _this3.environment.lookup(_this3.operation.fragment, _this3.operation);

      _this3.onChange(snapshot);

      _this3.rootSubscription = _this3.environment.subscribe(snapshot, _this3.onChange);
      resolve();
    };

    var onError = function onError(error) {
      _this3.updateReadyState({
        error: error,
        props: null,
        retry: _this3.retry
      });

      resolve();
    };

    var useStoreSnapshot = !this.retrying && (this.fetchPolicy === 'store-and-network' || this.fetchPolicy === 'store-or-network') && this.environment.check(this.operation).status === 'available';

    if (!(this.fetchPolicy === 'store-or-network' && useStoreSnapshot)) {
      try {
        this.pendingRequest = this.environment.execute({
          operation: this.operation,
          cacheConfig: this.cacheConfig
        })["finally"](function () {
          _this3.pendingRequest = null;
        }).subscribe({
          next: onSnapshot,
          error: onError
        });
      } catch (error) {
        onError(error);
        return;
      }
    } // Only use the store snapshot if the network layer doesn't synchronously
    // resolve a snapshot, to match <QueryRenderer>.


    if (!snapshot && useStoreSnapshot) {
      onSnapshot();
    }

    if (!snapshot && this.retryingAfterError) {
      this.updateReadyState({
        error: null,
        props: null,
        retry: null
      });
    }
  };

  _proto.updateReadyState = function updateReadyState(readyState) {
    var _context;

    this.readyState = readyState;

    _forEachInstanceProperty(_context = this.listeners).call(_context, function (listener) {
      listener();
    });
  };

  _proto.subscribe = function subscribe(listener) {
    this.listeners.push(listener);
  };

  _proto.unsubscribe = function unsubscribe(listener) {
    var _context2;

    this.listeners = _filterInstanceProperty(_context2 = this.listeners).call(_context2, function (item) {
      return item !== listener;
    });
  };

  _proto.retain = function retain() {
    return this.environment.retain(this.operation);
  };

  _proto.dispose = function dispose() {
    this.fetchPromise = null;

    if (this.selectionReference) {
      this.selectionReference.dispose();
    }

    if (this.pendingRequest) {
      this.pendingRequest.unsubscribe();
    }

    if (this.rootSubscription) {
      this.rootSubscription.dispose();
    }
  };

  _proto.getQueryName = function getQueryName() {
    return this.operation.root.node.name;
  };

  return QuerySubscription;
}();

export { QuerySubscription as default };

==> found-relay-0.9.0.tgz: package/es/QuerySubscription.js <==
import { createOperationDescriptor, getRequest } from 'relay-runtime';
export default class QuerySubscription {
  constructor({
    environment,
    query,
    variables,
    cacheConfig,
    fetchPolicy
  }) {
    this.onChange = snapshot => {
      this.updateReadyState({
        error: null,
        props: snapshot.data,
        retry: this.retry
      });
    };

    this.retry = () => {
      this.retrying = true;
      this.retryingAfterError = !!this.readyState.error;
      this.dispose();
      this.execute(() => {});
    };

    this.environment = environment;
    this.query = query;
    this.variables = variables;
    this.cacheConfig = cacheConfig;
    this.fetchPolicy = fetchPolicy;
    this.operation = createOperationDescriptor(getRequest(query), variables);
    this.fetchPromise = null;
    this.selectionReference = null;
    this.pendingRequest = null;
    this.rootSubscription = null;
    this.retrying = false;
    this.retryingAfterError = false;
    this.readyState = {
      error: null,
      props: null,
      retry: null
    };
    this.listeners = [];
    this.relayContext = {
      environment: this.environment,
      variables: this.operation.request.variables
    };
  }

  fetch() {
    if (!this.fetchPromise) {
      this.fetchPromise = new Promise(resolve => {
        this.execute(resolve);
      });
    }

    return this.fetchPromise;
  }

  execute(resolve) {
    let snapshot;
    this.selectionReference = this.retain();

    const onSnapshot = () => {
      if (snapshot) {
        return;
      }

      snapshot = this.environment.lookup(this.operation.fragment, this.operation);
      this.onChange(snapshot);
      this.rootSubscription = this.environment.subscribe(snapshot, this.onChange);
      resolve();
    };

    const onError = error => {
      this.updateReadyState({
        error,
        props: null,
        retry: this.retry
      });
      resolve();
    };

    const useStoreSnapshot = !this.retrying && (this.fetchPolicy === 'store-and-network' || this.fetchPolicy === 'store-or-network') && this.environment.check(this.operation).status === 'available';

    if (!(this.fetchPolicy === 'store-or-network' && useStoreSnapshot)) {
      try {
        this.pendingRequest = this.environment.execute({
          operation: this.operation,
          cacheConfig: this.cacheConfig
        }).finally(() => {
          this.pendingRequest = null;
        }).subscribe({
          next: onSnapshot,
          error: onError
        });
      } catch (error) {
        onError(error);
        return;
      }
    } // Only use the store snapshot if the network layer doesn't synchronously
    // resolve a snapshot, to match <QueryRenderer>.


    if (!snapshot && useStoreSnapshot) {
      onSnapshot();
    }

    if (!snapshot && this.retryingAfterError) {
      this.updateReadyState({
        error: null,
        props: null,
        retry: null
      });
    }
  }

  updateReadyState(readyState) {
    this.readyState = readyState;
    this.listeners.forEach(listener => {
      listener();
    });
  }

  subscribe(listener) {
    this.listeners.push(listener);
  }

  unsubscribe(listener) {
    this.listeners = this.listeners.filter(item => item !== listener);
  }

  retain() {
    return this.environment.retain(this.operation);
  }

  dispose() {
    this.fetchPromise = null;

    if (this.selectionReference) {
      this.selectionReference.dispose();
    }

    if (this.pendingRequest) {
      this.pendingRequest.unsubscribe();
    }

    if (this.rootSubscription) {
      this.rootSubscription.dispose();
    }
  }

  getQueryName() {
    return this.operation.root.node.name;
  }

}
